@@ -10,9 +10,9 @@ from scisel import *
 # an simpler version of avgcyc
 def avgcyc(x,n):
     """ calculate averaged cycle"""
-    xout = np.zeros([n+1]+list(np.shape(x)[1:]))
+    xout = zeros([n+1]+list(array(x).shape[1:]))
     for ix in range(n):
-        xout[ix] = np.mean(x[ix::n],axis=0)
+        xout[ix] = mean(x[ix::n],axis=0)
     xout[n] = xout[0] 
     return xout
 
